==> haskell-crypto-cipher-types-0.0.9-326-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-cipher-types
version:              0.0.9
visibility:           public
id:                   crypto-cipher-types-0.0.9-JlEUy6YMnlQJGxVQmgyp8z
key:                  crypto-cipher-types-0.0.9-JlEUy6YMnlQJGxVQmgyp8z
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-crypto-cipher
synopsis:             Generic cryptography cipher types
description:          Generic cryptography cipher types
category:             Cryptography
abi:                  233b89556e2b06159b69a205ff89ba1b
exposed:              True
exposed-modules:      Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules:
    Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
    Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
    Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
    Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypto-cipher-types-0.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-cipher-types
hs-libraries:         HScrypto-cipher-types-0.0.9-JlEUy6YMnlQJGxVQmgyp8z
depends:
    base-4.16.4.0 byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
    bytestring-0.11.4.0 securemem-0.1.10-EDfBRjlOKD136c0ZXJQIUL

haddock-interfaces:
    /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-356.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-cipher-types
version:              0.0.9
visibility:           public
id:                   crypto-cipher-types-0.0.9-56ZYVGDFxwtG8TJEc7UjH2
key:                  crypto-cipher-types-0.0.9-56ZYVGDFxwtG8TJEc7UjH2
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-crypto-cipher
synopsis:             Generic cryptography cipher types
description:          Generic cryptography cipher types
category:             Cryptography
abi:                  304c209f5dd29fc19d8abc03d3855f8e
exposed:              True
exposed-modules:      Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules:
    Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
    Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
    Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
    Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-cipher-types-0.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-cipher-types-0.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-cipher-types
hs-libraries:         HScrypto-cipher-types-0.0.9-56ZYVGDFxwtG8TJEc7UjH2
depends:
    base-4.17.2.1 byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY
    bytestring-0.11.5.3 securemem-0.1.10-EOlWoZVaToP2K6s5wFpHsU

haddock-interfaces:
    /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
